==> wechat-client-sdk-v1.0.10.tar: wechat-client-sdk-v1.0.10/httpclient/HttpUtil.go <==
package httpclient

import (
	"bytes"
	"encoding/json"
	"io/ioutil"
	"net/http"
)

// HttpClient 本项目中使用的http客户端
var HttpClient *http.Client

func init() {
	HttpClient = &http.Client{}
	//HttpClient.Timeout = config.Conf.Http.Client.Timeout * time.Millisecond //设置请求超时时间
}

// Get get方法的http请求，返回原始字符串
func Get(url string) ([]byte, error) {
	rep, err := HttpClient.Get(url)
	if err != nil {
		return nil, err
	}
	defer rep.Body.Close()
	data, err := ioutil.ReadAll(rep.Body)
	if err != nil {
		return nil, err
	}
	return data, nil
}

// GetWithHeader get方法的http请求，返回原始字符串
func GetWithHeader(url string, header *map[string]string) ([]byte, error) {
	req, err := http.NewRequest("GET", url, nil)
	if err != nil {
		return nil, err
	}
	//设置header
	req.Header.Set("Content-Type", "application/json;charset=UTF-8")
	if header != nil {
		for k, v := range *header {
			req.Header.Set(k, v)
		}
	}
	//发送请求
	rep, err := HttpClient.Do(req)
	if err != nil {
		return nil, err
	}
	defer rep.Body.Close()

	//处理返回值
	data, err := ioutil.ReadAll(rep.Body)
	if err != nil {
		return nil, err
	}
	return data, nil
}

// Post post请求，json
// url 请求地址
// header header参数
// badyParam body参数
func Post(url string, header *map[string]string, bodyParam interface{}) ([]byte, error) {
	//处理body参数
	var bt []byte
	if bodyParam != nil {
		b, err := json.Marshal(bodyParam)
		if err != nil {
			return nil, err
		}
		bt = b
	}
	//创建post请求
	req, err := http.NewRequest("POST", url, bytes.NewReader(bt))
	if err != nil {
		return nil, err
	}
	//设置header
	req.Header.Set("Content-Type", "application/json;charset=UTF-8")
	if header != nil {
		for k, v := range *header {
			req.Header.Set(k, v)
		}
	}
	//发送请求
	rep, err := HttpClient.Do(req)
	if err != nil {
		return nil, err
	}
	defer rep.Body.Close()

	//处理返回值
	data, err := ioutil.ReadAll(rep.Body)
	if err != nil {
		return nil, err
	}
	return data, nil
}

==> wechat-client-sdk-v1.0.11.tar: wechat-client-sdk-v1.0.11/httpclient/HttpUtil.go <==
package httpclient

import (
	"bytes"
	"encoding/json"
	"io/ioutil"
	"net/http"
)

// HttpClient 本项目中使用的http客户端
var httpClient *http.Client = &http.Client{}

// Get get方法的http请求，返回原始字符串
func Get(url string) ([]byte, error) {
	rep, err := httpClient.Get(url)
	if err != nil {
		return nil, err
	}
	defer rep.Body.Close()
	data, err := ioutil.ReadAll(rep.Body)
	if err != nil {
		return nil, err
	}
	return data, nil
}

// GetWithHeader get方法的http请求，返回原始字符串
func GetWithHeader(url string, header *map[string]string) ([]byte, error) {
	req, err := http.NewRequest("GET", url, nil)
	if err != nil {
		return nil, err
	}
	//设置header
	req.Header.Set("Content-Type", "application/json;charset=UTF-8")
	if header != nil {
		for k, v := range *header {
			req.Header.Set(k, v)
		}
	}
	//发送请求
	rep, err := httpClient.Do(req)
	if err != nil {
		return nil, err
	}
	defer rep.Body.Close()

	//处理返回值
	data, err := ioutil.ReadAll(rep.Body)
	if err != nil {
		return nil, err
	}
	return data, nil
}

// Post post请求，json
// url 请求地址
// header header参数
// badyParam body参数
func Post(url string, header *map[string]string, bodyParam interface{}) ([]byte, error) {
	//处理body参数
	var bt []byte
	if bodyParam != nil {
		b, err := json.Marshal(bodyParam)
		if err != nil {
			return nil, err
		}
		bt = b
	}
	//创建post请求
	req, err := http.NewRequest("POST", url, bytes.NewReader(bt))
	if err != nil {
		return nil, err
	}
	//设置header
	req.Header.Set("Content-Type", "application/json;charset=UTF-8")
	if header != nil {
		for k, v := range *header {
			req.Header.Set(k, v)
		}
	}
	//发送请求
	rep, err := httpClient.Do(req)
	if err != nil {
		return nil, err
	}
	defer rep.Body.Close()

	//处理返回值
	data, err := ioutil.ReadAll(rep.Body)
	if err != nil {
		return nil, err
	}
	return data, nil
}
